@@ -36,12 +36,14 @@ def raster_geometry_mask(dataset, shapes, all_touched=False, invert=False,
         If False (default), include a pixel only if its center is within one of
         the shapes, or if it is selected by Bresenham's line algorithm.
     invert : bool (opt)
-        If False (default), mask will be `False` inside shapes and `True`
-        outside.  If True, mask will be `True` inside shapes and `False`
-        outside.
+        Determines whether to mask pixels outside or inside the shapes.
+        The default (False) is to mask pixels outside shapes.
+        When invert is used with crop, the area outside the cropping window is
+        considered selected and should be processed accordingly by the user.
     crop : bool (opt)
-        Whether to crop the dataset to the extent of the shapes. Defaults to
-        False.
+        Crop the dataset to the extent of the shapes. Useful for
+        processing rasters where shapes cover only a relatively small area.
+        Defaults to False.
     pad : bool (opt)
         If True, the features will be padded in each direction by
         one half of a pixel prior to cropping dataset. Defaults to False.
@@ -55,8 +57,9 @@ def raster_geometry_mask(dataset, shapes, all_touched=False, invert=False,
 
         Three elements:
 
-            mask : numpy ndarray of type 'bool'
-                Mask that is `True` outside shapes, and `False` within shapes.
+            mask : np.ndarray of type 'bool'
+                Mask suitable for use in a MaskedArray where valid pixels are
+                marked `False` and invalid pixels are marked `True`.
 
             out_transform : affine.Affine()
                 Information for mapping pixel coordinates in `masked` to another
@@ -66,9 +69,6 @@ def raster_geometry_mask(dataset, shapes, all_touched=False, invert=False,
                 Window within original raster covered by shapes.  None if crop
                 is False.
     """
-    if crop and invert:
-        raise ValueError("crop and invert cannot both be True.")
-
     if crop and pad:
         pad_x = pad_width
         pad_y = pad_width
@@ -76,12 +76,8 @@ def raster_geometry_mask(dataset, shapes, all_touched=False, invert=False,
         pad_x = 0
         pad_y = 0
 
-    north_up = dataset.transform.e <= 0
-    rotated = dataset.transform.b != 0 or dataset.transform.d != 0
-
     try:
-        window = geometry_window(dataset, shapes, north_up=north_up, rotated=rotated,
-                                 pad_x=pad_x, pad_y=pad_y)
+        window = geometry_window(dataset, shapes, pad_x=pad_x, pad_y=pad_y)
 
     except WindowError:
         # If shapes do not overlap raster, raise Exception or UserWarning
@@ -93,7 +89,9 @@ def raster_geometry_mask(dataset, shapes, all_touched=False, invert=False,
                           'Are they in different coordinate reference systems?')
 
         # Return an entirely True mask (if invert is False)
-        mask = np.ones(shape=dataset.shape[-2:], dtype='bool') * (not invert)
+        mask = np.ones(shape=dataset.shape[-2:], dtype=bool)
+        if invert:
+            mask = ~mask
         return mask, dataset.transform, None
 
     if crop:
@@ -158,7 +156,7 @@ def mask(dataset, shapes, all_touched=False, invert=False, nodata=None,
 
         Two elements:
 
-            masked : numpy ndarray or numpy.ma.MaskedArray
+            masked : numpy.ndarray or numpy.ma.MaskedArray
                 Data contained in the raster after applying the mask. If
                 `filled` is `True` and `invert` is `False`, the return will be
                 an array where pixels outside shapes are set to the nodata value
