@@ -8,14 +8,7 @@ import click
 
 import rasterio
 from rasterio.rio import options
-from rasterio.transform import Affine, from_gcps
-from rasterio.serde import to_json
-
-
-@to_json.register(Affine)
-def _(obj):
-    """Convert an Affine (version 3) obj to a tuple."""
-    return obj._astuple
+from rasterio.transform import from_gcps
 
 
 @click.command(short_help="Print information about a data file.")
@@ -132,11 +125,8 @@ def info(ctx, input, aspect, indent, namespace, meta_member, verbose, bidx,
                 else:
                     click.echo(info[meta_member])
             else:
-                click.echo(
-                    json.dumps(info, sort_keys=True, indent=indent, default=to_json)
-                )
+                click.echo(json.dumps(info, sort_keys=True, indent=indent))
 
         elif aspect == 'tags':
             click.echo(
-                json.dumps(src.tags(ns=namespace), indent=indent, default=to_json)
-            )
+                json.dumps(src.tags(ns=namespace), indent=indent))
