@@ -1,6 +1,7 @@
 """Raster warping and reprojection."""
 
 from math import ceil, floor
+import warnings
 
 from affine import Affine
 import numpy as np
@@ -10,8 +11,8 @@ import rasterio
 from rasterio._base import _transform
 from rasterio.crs import CRS
 from rasterio.enums import Resampling
-from rasterio.env import ensure_env, require_gdal_version
-from rasterio.errors import TransformError, RPCError
+from rasterio.env import ensure_env
+from rasterio.errors import TransformError, RPCError, RasterioDeprecationWarning
 from rasterio.transform import array_bounds
 from rasterio._warp import (
     _calculate_default_transform,
@@ -61,17 +62,14 @@ def transform(src_crs, dst_crs, xs, ys, zs=None):
 
 
 @ensure_env
-@require_gdal_version('2.1', param='antimeridian_cutting', values=[False],
-                      is_max_version=True,
-                      reason="Antimeridian cutting is always enabled on "
-                             "GDAL >= 2.2")
 def transform_geom(
-        src_crs,
-        dst_crs,
-        geom,
-        antimeridian_cutting=True,
-        antimeridian_offset=10.0,
-        precision=-1):
+    src_crs,
+    dst_crs,
+    geom,
+    antimeridian_cutting=None,
+    antimeridian_offset=None,
+    precision=-1,
+):
     """Transform geometry from source coordinate reference system into target.
 
     Parameters
@@ -82,14 +80,10 @@ def transform_geom(
     dst_crs: CRS or dict
         Target coordinate reference system.
     geom: GeoJSON like dict object or iterable of GeoJSON like objects.
-    antimeridian_cutting: bool, optional
-        If True, cut geometries at the antimeridian, otherwise geometries
-        will not be cut (default).  If False and GDAL is 2.2.0 or newer
-        an exception is raised.  Antimeridian cutting is always on as of
-        GDAL 2.2.0 but this could produce an unexpected geometry.
+    antimeridian_cutting: bool
+        DEPRECATED: Always enabled since GDAL 2.2.
     antimeridian_offset: float
-        Offset from the antimeridian in degrees (default: 10) within which
-        any geometries will be split.
+        DEPRECATED: No longer has any effect since GDAL 2.2.
     precision: float
         If >= 0, geometry coordinates will be rounded to this number of decimal
         places after the transform operation, otherwise original coordinate
@@ -100,14 +94,18 @@ def transform_geom(
     out: GeoJSON like dict object or list of GeoJSON like objects.
         Transformed geometry(s) in GeoJSON dict format
     """
-
+    if antimeridian_cutting is not None or antimeridian_offset is not None:
+        warnings.warn(
+            "The antimeridian_cutting and antimeridian_offset parameters are "
+            "deprecated and no longer have any effect.",
+            RasterioDeprecationWarning,
+        )
     return _transform_geom(
         src_crs,
         dst_crs,
         geom,
-        antimeridian_cutting,
-        antimeridian_offset,
-        precision)
+        precision,
+    )
 
 
 def transform_bounds(
@@ -382,7 +380,7 @@ def reproject(
                 (int(dst_count), int(dst_height), int(dst_width)), dtype=source.dtype
             )
             if masked:
-                destination = np.ma.masked_array(destination).filled(dst_nodata)
+                destination = np.ma.masked_array(destination)
 
     dest = _reproject(
         source,
