@@ -15,15 +15,11 @@ def test_warning(tmpdir, caplog):
     with rasterio.Env(GDAL_VALIDATE_CREATION_OPTIONS=True):
         rasterio.open(str(tmpdir.join("test.tif")), "w", **profile)
 
-    assert set(
-        [
+    assert {
             "CPLE_NotSupported in driver GTiff does not support creation option COMPRESSION",
             "CPLE_NotSupported in driver GTiff does not support creation option FOO",
-        ]
-    ) <= set(
-        [
+    } <= {
             rec.message
             for rec in caplog.records
             if rec.levelno == logging.WARNING and rec.name == "rasterio._env"
-        ]
-    )
+    }
