@@ -15,7 +15,8 @@ def test_tiled(tmpdir, runner):
     )
     assert result.exit_code == 0
     with rasterio.open(outputname) as src:
-        assert not src.is_tiled
+        blockysize, blockxsize = src.block_shapes[0]
+        assert blockxsize == src.width
 
 
 def test_format(tmpdir, runner):
@@ -46,7 +47,7 @@ def test_format_short(tmpdir, runner):
     ('jpeg', 'JPEG'),
 ])
 def test_autodetect_format(tmpdir, runner, extension, driver):
-    outputname = str(tmpdir.join("test.{}".format(extension)))
+    outputname = str(tmpdir.join(f"test.{extension}"))
     result = runner.invoke(
         main_group,
         ['convert', 'tests/data/RGB.byte.tif', outputname])
@@ -130,8 +131,8 @@ def test_dtype_rescaling_float64(tmpdir, runner):
     assert result.exit_code == 0
     with rasterio.open(outputname) as src:
         for band in src.read():
-            assert round(band.min() + 1.0, 6) == 0.0
-            assert round(band.max() - 1.0, 6) == 0.0
+            assert round(band.min(), 6) == -0.992157
+            assert round(band.max(), 6) == 1.0
 
 
 def test_rgb(tmpdir, runner):
