@@ -1,16 +1,15 @@
 import json
 
-import boto3
 import pytest
 
 import rasterio
 from rasterio.rio.main import main_group
 
-from .conftest import requires_gdal32, credentials
+from .conftest import credentials
 
 
 with rasterio.Env() as env:
-    HAVE_NETCDF = 'NetCDF' in env.drivers().keys()
+    HAVE_NETCDF = "netCDF" in env.drivers().keys()
 
 
 def test_env(runner):
@@ -153,7 +152,7 @@ def test_info_stats(runner):
         main_group, ['info', 'tests/data/RGB.byte.tif', '--tell-me-more'])
     assert result.exit_code == 0
     assert '"max": 255.0' in result.output
-    assert '"min": 0.0' in result.output
+    assert '"min": 1.0' in result.output
 
 
 def test_info_stats_only(runner):
@@ -161,7 +160,7 @@ def test_info_stats_only(runner):
         main_group,
         ['info', 'tests/data/RGB.byte.tif', '--stats', '--bidx', '2'])
     assert result.exit_code == 0
-    assert result.output.startswith("0.0 255.0")
+    assert result.output.startswith("1.0 255.0")
 
 
 def test_info_colorinterp(runner):
@@ -423,7 +422,6 @@ def test_info_aws_unsigned(runner):
     assert result.exit_code == 0
 
 
-@requires_gdal32(reason="Unsigned Azure requests require GDAL ~= 3.2")
 @pytest.mark.network
 @pytest.mark.skip(reason="Undiagnosed problem accessing this file")
 def test_info_azure_unsigned(monkeypatch, runner):
