@@ -1,4 +1,3 @@
-import attr
 import rasterio
 from rasterio.rpc import RPC
 
@@ -176,13 +175,6 @@ def test_rpcs_write_read_rpcs(tmpdir):
         assert isinstance(rpcs, RPC)
         expected = TEST_RPCS_FROM_GDAL.copy()
 
-        # GDAL < 3.3 does not ensure ERR_BIAS and ERR_RAND are written out
-        # so we wont either
-        expected.pop("ERR_BIAS")
-        expected.pop("ERR_RAND")
-        rpcs.err_bias = None
-        rpcs.err_rand = None
-
         assert sorted(rpcs.to_gdal().keys()) == sorted(expected.keys())
 
         rpcs.lat_off = 48
