@@ -7,12 +7,10 @@ import affine
 import numpy as np
 import pytest
 
-from .conftest import gdal_version
-
 import rasterio
 from rasterio.drivers import blacklist
 from rasterio.enums import MaskFlags, Resampling
-from rasterio.env import Env, GDALVersion
+from rasterio.env import Env
 from rasterio.errors import RasterioIOError
 
 def test_validate_dtype_None(tmpdir):
@@ -117,10 +115,7 @@ def test_write_sbyte(tmpdir):
 
     info = subprocess.check_output(["gdalinfo", "-stats", name]).decode('utf-8')
     assert "Minimum=-33.000, Maximum=-33.000, Mean=-33.000, StdDev=0.000" in info
-    if gdal_version < GDALVersion(3, 7):
-        assert 'SIGNEDBYTE' in info
-    else:
-        assert 'Int8' in info
+    assert 'Int8' in info
 
 
 @pytest.mark.gdalbin
@@ -254,10 +249,10 @@ def test_write_crs_transform_2(tmpdir, monkeypatch):
             driver='GTiff', width=100, height=100, count=1,
             crs='EPSG:32618',
             transform=transform,
-            dtype=rasterio.ubyte) as s:
-        s.write(a, indexes=1)
+            dtype=rasterio.ubyte) as src:
+        src.write(a, indexes=1)
 
-    assert s.crs.to_epsg() == 32618
+    assert src.crs.to_epsg() == 32618
     info = subprocess.check_output(["gdalinfo", name]).decode('utf-8')
     assert 'UTM zone 18N' in info
     # make sure that pixel size is nearly the same as transform
@@ -443,6 +438,25 @@ def test_write_cog(tmpdir, path_rgb_byte_tif):
             cog.write(src.read())
 
 
+def test_write_cog__from_numpy(tmp_path):
+    data = np.zeros((100, 100))
+    profile = {
+        "width": data.shape[0],
+        "height": data.shape[1],
+        "count": 1,
+        "dtype": np.uint8,
+        "transform": affine.Affine(3.5, 0.0, 558838.0, 0.0, -3.5, 5927362.0),
+        "crs": 32630,
+        "nodata": 0,
+        "driver": "COG",
+        "compress": "DEFLATE",
+    }
+
+    with open(tmp_path / "bar.tiff", "wb") as f2:
+        with rasterio.open(f2, mode="w", **profile) as ds:
+            ds.write(data, 1)
+
+
 def test_write_masked(tmp_path):
     """Verify that masked arrays are filled when written."""
     data = np.ma.masked_less_equal(np.array([[0, 1, 2]], dtype="uint8"), 1)
